Learn R Programming

kantorovich (version 3.1.0)

edistances: Extremal distances

Description

Compute the distances at the extreme joinings.

Usage

edistances(mu, nu, dist = NULL, ...)

Value

A list with two components: the extreme joinings in a list and the distances in a vector.

Arguments

mu

(row margins) probability measure in numeric or bigq/character mode

nu

(column margins) probability measure in numeric or bigq/character mode

dist

function or matrix, the distance to be minimized on average. If NULL, the 0-1 distance is used.

...

arguments passed to dist