Compute the distances at the extreme joinings.
edistances(mu, nu, dist = NULL, ...)A list with two components: the extreme joinings in a list and the distances in a vector.
(row margins) probability measure in numeric or bigq/character mode
(column margins) probability measure in numeric or bigq/character mode
function or matrix, the distance to be minimized on average.
If NULL, the 0-1 distance is used.
arguments passed to dist