Rdocumentation
powered by
Learn R Programming
kantorovich (version 1.0.0)
edistances: Extremal distances
Description
Compute the distances at the extreme points
Usage
edistances(mu, nu, dist = NULL, ...)
Arguments
mu
row margins
nu
column margins
dist
function or matrix, the distance to be minimized on average. If
NULL
, the 0-1 distance is used.
...
arguments passed to
dist
Value
a list with two components: the extreme joinings in a list and the distances in a vector