kantorovich-package: Kantorovich Distance Between Probability Measures
Description
Computes the Kantorovich distance between two probability measures on a finite set.
To learn more, start with the vignettes:
browseVignettes(package="kantorovich").
If you encounter a bug, or if you have a suggestion to improve the package, please file an issue on the github repo https://github.com/stla/kantorovich.